==> xwiki-commons-stability-6.3-sources.jar: org/xwiki/stability/Unstable.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.stability;

import java.lang.annotation.Documented;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

/**
 * Indicates that a java type (class, interface, method, etc) API is still unstable and subject to change at any time.
 * This means that the XWiki deprecation policy doesn't apply yet on the annotated type.
 *
 * @version $Id: df85a5b6bcb98dfb8c82d963594125d7031981a8 $
 * @since 5.0M1
 */
@Documented
@Retention(RUNTIME)
@Target({ TYPE, METHOD })
@Inherited
public @interface Unstable
{
    /**
     * An optional explanation about the reason why the java type is unstable.
     */
    String value() default "";
}

==> xwiki-commons-stability-16.10.11-sources.jar: org/xwiki/stability/Unstable.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.stability;

import java.lang.annotation.Documented;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.CONSTRUCTOR;
import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

/**
 * Indicates that a java type (class, interface, method, etc) API is still unstable and subject to change at any time.
 * This means that the XWiki deprecation policy doesn't apply yet on the annotated type.
 *
 * @version $Id: e1495acea6dab54e18a8c9dfac98135341e9c035 $
 * @since 5.0M1
 */
@Documented
@Retention(RUNTIME)
@Target({ TYPE, METHOD, FIELD, CONSTRUCTOR })
@Inherited
public @interface Unstable
{
    /**
     * @return an optional explanation about the reason why the java type is unstable.
     */
    String value() default "";
}
